from sqlalchemy import Column, Integer, String, Boolean, ForeignKey, Text, NUMERIC, BLOB, REAL, DateTime
from sqlalchemy.orm import relationship
from sqlalchemy.ext.declarative import declarative_base
